@@ -6,6 +6,9 @@ from string import Template
 
 def create_project(root_path, output_path_root):
     root_path = root_path / 'project'
+    packages_path = output_path_root / 'packages'
+    if not packages_path.is_dir():
+        packages_path.mkdir()
     for path in sorted(root_path.rglob('*')):
         first_dir = path.relative_to(root_path).parts [0]
         if first_dir == '.git' or first_dir == '.ipynb_checkpoints' or path.suffix == '.sh' or "__pycache__" in path.relative_to(root_path).parts:
@@ -16,8 +19,6 @@ def create_project(root_path, output_path_root):
                 output_path_dir.mkdir()
             continue
         text = path.read_text()
-        # print(text)
-        # text = text.replace('recoform', package_name)
         
         output_path = output_path_root / Path(*[p if p!='recoform' else package_name for p in path.relative_to(root_path).parts])
         output_path.write_text(text)
